conn2svg Python library
=======================

.. start-intro

**conn2svg** - Connector pinout drawing (SVG) generator used to automatically generate interface control documents.

Installing
----------

As usual, you can use package installer for Python:

.. code:: bash

   pip install conn2svg

.. end-intro

Documentation
-------------

Get the latest documentation build: `partmanager.github.io/conn2svg <https://partmanager.github.io/conn2svg>`_.
